@@ -1,4 +1,3 @@
-
 # ------------------------- MINUIT PART ----------------
 #  pip3 install iminout  numba_stats numpy
 from iminuit import cost, Minuit
@@ -86,15 +85,17 @@ def main(x,y,dy, polorder = None):
     c2 = cost.LeastSquares(x, y, dy, model_chi2)
 
     bgest = (y[0]+y[-1])/2 * len(x)
-    bgest = 1
+    bgest = y.min() * len(x)
     areaest = sum(y)-bgest
-    eneest = x.mean()
+    eneest = x[y.argmax()]
+
+
 
     m2 = Minuit(c2,
                 area = areaest,
                 channel = eneest,
                 fwhm = 5,
-                a=bgest, b=1  )
+                a=1, b=1  )
 
     print_errors(m2, 0) # my nice table at end
 
@@ -214,6 +215,7 @@ def main(x,y,dy, polorder = None):
 
     res['range']    = ( x[0], x[-1] )
 
+
     res['area']    = m2.values['area']
     err            = m2.errors['area']
     if chi2dof>1:
@@ -221,7 +223,8 @@ def main(x,y,dy, polorder = None):
     res['darea']   = err
 
 
-    res['channel']    = m2.values['channel']
+
+    res['channel'] = m2.values['channel']
     err            = m2.errors['channel']
     if chi2dof>1:
             err = err * np.sqrt(chi2dof)
@@ -230,8 +233,14 @@ def main(x,y,dy, polorder = None):
 
 
     res['fwhm']    = m2.values['fwhm']
+    err            = m2.errors['fwhm']
+    if chi2dof>1:
+            err = err * np.sqrt(chi2dof)
+    res['dfwhm']   = err
+
 
 
     res['diff_fit_int_proc'] = 100*abs(m2.values['area'] - sigarea[0])/(m2.values['area'] + sigarea[0])/2
+
     return res
     # return (yf,yf_l,yf_h)
